ContactQuery class

A contact query

Constructors

ContactQuery()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryContact(String? address) → Future<Contact?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

inProgress ↔ Map<String, bool>
getter/setter pair
queried ↔ Map<String, Contact>
getter/setter pair